@@ -199,6 +199,9 @@ class AMQPData(GeneralData):
         for method_frame, properties, body in self.channel.consume(
                 *consumer_args):
             try:
+                rprint(":::>")
+                bprint(body)
+                rprint(":::>")
                 strb = str(body, 'utf-8').replace("'", "\"")
                 new_json = json.loads(strb)
             except Exception as e:
